// SPACK Options.cs
// Written by David J. Stein, Esq. See "License.html" for terms and conditions of use.
//
// This module contains the code for viewing an image from SPACK in a small, standalone dialog window.
// (Adapted from a similar module in Phobos for the same purpose.)

#region Using declarations

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

#endregion

namespace SPACK_NS {

	public partial class SPACKImageDialog : Form {

		#region Variables and initialization code

		public string strFile;
		int iImageWidth, iImageHeight;
		
		public SPACKImageDialog(string strFile) {
			InitializeComponent();
			this.strFile = strFile;
		}

		#endregion

		#region Event handlers

		private void PhobosImageDialog_Load(object sender, EventArgs e) {
			string strFilename = System.IO.Path.GetFileNameWithoutExtension(strFile);
			this.Name = "SPACK Picture - " + strFilename;
			System.IO.FileStream stream = new System.IO.FileStream(strFile, System.IO.FileMode.Open);
			Image image = Image.FromStream(stream);
			stream.Close();
			iImageWidth = image.Width;
			iImageHeight = image.Height;
			this.pbPicture.BackgroundImage = image;
			SetSize();
		}

		private void PhobosImageDialog_Resize(object sender, EventArgs e) {
			SetSize();
		}

		#endregion

		#region Helper functions

		private void SetSize() {
			if ((iImageWidth > 0) && (iImageHeight > 0)) {
				if (iImageWidth > iImageHeight) {
					int iWidth = Width - 16;
					int iHeight = (Width - 16) * iImageHeight / iImageWidth;
					if (iHeight > Height - 32) {
						iWidth = iWidth * (Height - 32) / iHeight;
						iHeight = Height - 32;
					}
					int iWidthMargin = (Width - 16) - iWidth;
					int iHeightMargin = (Height - 32) - iHeight;
					pbPicture.Left = 2 + iWidthMargin / 2;
					pbPicture.Width = iWidth;
					pbPicture.Top = 2 + iHeightMargin / 2;
					pbPicture.Height = iHeight;
				} else {
					int iHeight = Height - 32;
					int iWidth = (Height - 32) * iImageWidth / iImageHeight;
					if (iWidth > Width - 16) {
						iHeight = iHeight * (Width - 16) / iWidth;
						iWidth = Width - 16;
					}
					int iHeightMargin = (Height - 32) - iHeight;
					int iWidthMargin = (Width - 16) - iWidth;
					pbPicture.Left = 2 + iWidthMargin / 2;
					pbPicture.Width = iWidth;
					pbPicture.Top = 2 + iHeightMargin / 2;
					pbPicture.Height = iHeight;
				}
			}
		}

		#endregion

	}
}
