// SPACK Options.cs
// Written by David J. Stein, Esq. See "License.html" for terms and conditions of use.
//
// This module contains the code for a program options dialog. Just a few simple UI
// event handlers, and a read and write function. Pretty simple.

#region Using declarations

using System;
using System.IO;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.Xml.Serialization;

#endregion

namespace SPACK_NS {

	public partial class SPACK_Options : Form {

		#region Variables and initalization code

		public SPACK_Options_Set options_set = new SPACK_Options_Set();

		public SPACK_Options(SPACK_Options_Set options_set) {
			InitializeComponent();
			this.options_set = options_set;
		}

		#endregion

		#region Event handlers

		private void SPACK_Options_Load(object sender, EventArgs e) {
			txtHTMLTemplate.Text = options_set.strHTMLTemplate;
			txtDefaultBasePath.Text = options_set.strDefaultBasePath;
			nudResampleImagesValue.Value = options_set.iResampleImagesValue;
			if (options_set.strResampleMode == "Percent")
				rbResampleModePercent.Checked = true;
			else
				rbResampleModeAbsolute.Checked = true;
		}

		private void btnBrowseHTMLTemplate_Click(object sender, EventArgs e) {
			OpenFileDialog o = new OpenFileDialog();
			if (o.ShowDialog() == DialogResult.OK)
				txtHTMLTemplate.Text = o.FileName;
		}

		private void txtHTMLTemplate_TextChanged(object sender, EventArgs e) {
			options_set.strHTMLTemplate = txtHTMLTemplate.Text;
		}

		private void nudResampleImagesValue_ValueChanged(object sender, EventArgs e) {
			options_set.iResampleImagesValue = (int) nudResampleImagesValue.Value;
		}

		private void btnBrowseDefaultBasePath_Click(object sender, EventArgs e) {
			FolderBrowserDialog f = new FolderBrowserDialog();
			if (f.ShowDialog() == DialogResult.OK)
				txtDefaultBasePath.Text = f.SelectedPath + (f.SelectedPath.EndsWith(System.IO.Path.DirectorySeparatorChar + "") ? "" : System.IO.Path.DirectorySeparatorChar + "");
		}

		private void txtDefaultBasePath_TextChanged(object sender, EventArgs e) {
			options_set.strDefaultBasePath = txtDefaultBasePath.Text;
		}

		private void rbResampleModePercent_Click(object sender, EventArgs e) {
			if (rbResampleModeAbsolute.Checked != !rbResampleModePercent.Checked)
				rbResampleModeAbsolute.Checked = !rbResampleModePercent.Checked;
			if (rbResampleModePercent.Checked == true)
				options_set.strResampleMode = "Percent";
		}

		private void rbResampleModeAbsolute_CheckedChanged(object sender, EventArgs e) {
			if (rbResampleModeAbsolute.Checked != !rbResampleModePercent.Checked)
				rbResampleModeAbsolute.Checked = !rbResampleModePercent.Checked;
			if (rbResampleModeAbsolute.Checked == true)
				options_set.strResampleMode = "Absolute";
		}

		private void SPACK_Options_KeyDown(object sender, KeyEventArgs e) {
			if (e.KeyCode == Keys.Escape)
				Close();
		}

		private void btnSaveAndExit_Click(object sender, EventArgs e) {
			SaveOptions();
		}

		private void btnExitWithoutSaving_Click(object sender, EventArgs e) {
			this.DialogResult = DialogResult.Cancel;
			Close();
		}

		#endregion

		#region Load and Save functions

		public void SaveOptions() {
			try {
				XmlSerializer formatter = new XmlSerializer(typeof(SPACK_Options_Set));
				string strFilename = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location) + System.IO.Path.DirectorySeparatorChar + "SPACK.cfg";
				TextWriter file = new StreamWriter(strFilename, false);
				formatter.Serialize(file, options_set);
				file.Close();
				this.DialogResult = DialogResult.OK;
			} catch (Exception ex) {
				MessageBox.Show(ex.Message);
			}
			Close();
		}

		public static SPACK_Options_Set LoadOptions() {
			SPACK_Options_Set options_set = new SPACK_Options_Set();
			try {
				string strFilename = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location) + System.IO.Path.DirectorySeparatorChar + "SPACK.cfg";
				if (System.IO.File.Exists(strFilename) == true) {
					XmlSerializer formatter = new XmlSerializer(typeof(SPACK_Options_Set));
					TextReader file = new StreamReader(strFilename);
					options_set = (SPACK_Options_Set) formatter.Deserialize(file);					file.Close();
				}
			} catch {}
			return options_set;
		}

		#endregion

	}
}
